/*
 *	fhist - file history and comparison tools
 *	Copyright (C) 1993, 1994, 1998, 2002 Peter Miller;
 *	All rights reserved.
 *
 *	This program is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program; if not, write to the Free Software
 *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 *
 * MANIFEST: interface definition for fhist/diff.c
 */

#ifndef DIFF_H
#define DIFF_H

#include <main.h>

void diffhistory(char *inputname, char *outputname, char *editname1,
	char *editname2, int matchblab);
void cleanhistory(char *filename);
void checkhistory(char *filename);
void comphistory(char *filename);

#endif /* DIFF_H */
